# NeutroSpecUI

![Short-Tests](https://github.com/Aseraphyss/NeutroSpecUI/actions/workflows/short-tests.yml/badge.svg)
![Long-Test](https://github.com/Aseraphyss/NeutroSpecUI/actions/workflows/long-tests.yml/badge.svg)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

## Description

NeutroSpecUI is a user-friendly tool for neutron reflectivity data analysis, transforming a traditionally time-consuming and complex manual fitting process into an efficient and intuitive experience.

## Table of Contents

- [NeutroSpecUI](#neutrospecui)
  - [Description](#description)
  - [Table of Contents](#table-of-contents)
  - [Installation](#installation)
    - [Prerequisites](#prerequisites)
    - [Steps](#steps)
  - [Usage](#usage)
  - [Features](#features)
  - [Contributing](#contributing)

## Installation

### Prerequisites

- Python 3.10 or higher
- pip

### Steps

1. Install NeutroSpecUI using pip:

```sh
pip install NeutroSpecUI
```

## Usage

To use NeutroSpecUI, you can run the application from the command line.

```sh
python -m NeutroSpecUI
```

For more information on how to use the application, please refer to the [User Guide](https://github.com/Aseraphyss/NeutroSpecUI/wiki/Usage).

## Features

- Intuitive GUI for parameter input and data visualization
- Real-time updates with immediate visual feedback
- Flexible model fitting with support for custom models
- Data management capabilities to save and load configurations
- Cross-platform compatibility (Windows, Mac, Linux)

## Contributing

We welcome contributions and feedback from collaborators and researchers. Please feel free to open issues or submit pull requests to help improve the project. Nevertheless, please note that this project is part of a university course, and we stop maintaining it after the course ends in 2025.

For more information you can visit the Wiki [Contributing](https://github.com/Aseraphyss/NeutroSpecUI/wiki/Contributing).
